@@ -20,12 +20,15 @@ DATABASE_CREDS = 'database_credentials'
 DATABASE_SECURITY_GROUPS = 'database_security_groups'
 DATABASE_SECURITY_GROUP_RULES = 'database_security_group_rules'
 DATABASES = 'databases'
+LOAD_BALANCERS = 'load_balancers'
 SERVER_SECURITY_GROUPS = 'server_security_groups'
 SERVER_SECURITY_GROUP_RULES = 'server_security_group_rules'
 SERVER_COMMON_ATTRIBUTES = 'server_common_attributes'
 SERVERS = 'servers'
 SSH_KEYS = 'ssh_pub_keys'
 
+DYNAMIC_LB_SEC_GROUPS = '_load_balancer_sec_groups'
+
 # This is where the inter-resource dependencies are resolved.  Keep it simple
 # until it needs to be more complicated.
 #
@@ -57,9 +60,12 @@ STAGES = [
             DATABASES,
             SERVERS,
             ),
-
+        (
+            LOAD_BALANCERS,
+            ),
         (
             DATABASE_SECURITY_GROUP_RULES,
+            DYNAMIC_LB_SEC_GROUPS,
             ),
         ]
 
